summaryrefslogtreecommitdiffstats
path: root/src/aig/dar/darInt.h
diff options
context:
space:
mode:
authorAlan Mishchenko <alanmi@berkeley.edu>2007-07-26 08:01:00 -0700
committerAlan Mishchenko <alanmi@berkeley.edu>2007-07-26 08:01:00 -0700
commit054e2cd3a8ab4ada55db4def2d6ce7d309341e07 (patch)
treea951eeeafa90dc555cb6442151761190e0b5af6a /src/aig/dar/darInt.h
parent64dc240b904adafee78e2a66a1fc31b717f8985f (diff)
downloadabc-054e2cd3a8ab4ada55db4def2d6ce7d309341e07.tar.gz
abc-054e2cd3a8ab4ada55db4def2d6ce7d309341e07.tar.bz2
abc-054e2cd3a8ab4ada55db4def2d6ce7d309341e07.zip
Version abc70726
Diffstat (limited to 'src/aig/dar/darInt.h')
-rw-r--r--src/aig/dar/darInt.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/aig/dar/darInt.h b/src/aig/dar/darInt.h
index 0acd272c..b14d5c30 100644
--- a/src/aig/dar/darInt.h
+++ b/src/aig/dar/darInt.h
@@ -55,7 +55,8 @@ struct Dar_Cut_t_ // 6 words
{
unsigned uSign; // cut signature
unsigned uTruth : 16; // the truth table of the cut function
- unsigned Value : 12; // the value of the cut
+ unsigned Value : 11; // the value of the cut
+ unsigned fBest : 1; // marks the best cut
unsigned fUsed : 1; // marks the cut currently in use
unsigned nLeaves : 3; // the number of leaves
int pLeaves[4]; // the array of leaves
@@ -85,6 +86,7 @@ struct Dar_Man_t_
int nCutMemUsed; // memory used for cuts
// rewriting statistics
int nNodesInit; // the original number of nodes
+ int nNodesTried; // the number of nodes attempted
int nCutsAll; // all cut pairs
int nCutsTried; // computed cuts
int nCutsUsed; // used cuts